==> create-typescript-app-2.15.2.tgz: package/lib/blocks/blockREADME.js <==
import { z } from "zod";
import { base } from "../base.js";
function printAttributes(attributes) {
  return Object.entries(attributes).map(([key, value]) => `${key}="${value}"`).sort().join(" ");
}
const zBadge = z.object({
  alt: z.string(),
  comments: z.object({
    after: z.string(),
    before: z.string()
  }).optional(),
  href: z.string().optional(),
  src: z.string()
});
const blockREADME = base.createBlock({
  about: {
    name: "README.md"
  },
  addons: {
    badges: z.array(zBadge).default([]),
    notices: z.array(z.string()).default([]),
    sections: z.array(z.string()).default([])
  },
  produce({ addons, options }) {
    const { badges, notices, sections } = addons;
    const explainer = options.explainer && `
${options.explainer.join("\n")}
`;
    const logo = options.logo && `
<img ${printAttributes({ align: "right", ...options.logo })}>
`;
    return {
      files: {
        "README.md": `<h1 align="center">${options.title}</h1>

<p align="center">${formatDescription(options.description)}</p>

<p align="center">
${formatBadges(badges)}
</p>
${[logo, explainer].filter(Boolean).join("")}
## Usage

${options.usage}

## Development

See [\`.github/CONTRIBUTING.md\`](./.github/CONTRIBUTING.md), then [\`.github/DEVELOPMENT.md\`](./.github/DEVELOPMENT.md).
Thanks! ${options.emoji}
${sections.map((section) => `
${section}`).join("")}
${notices.length ? `
${notices.map((notice) => notice.trim()).join("\n\n")}` : ""}`
      }
    };
  }
});
function badgeSorter(a, b) {
  return removeEmojis(a.alt).localeCompare(removeEmojis(b.alt));
}
function formatBadge(badge) {
  const image = `<img alt="${badge.alt}" src="${badge.src}" />`;
  const tagged = badge.href ? `<a href="${badge.href}" target="_blank">${image}</a>` : image;
  const commented = badge.comments ? `${badge.comments.before}${tagged}${badge.comments.after}` : tagged;
  return `	${commented}`;
}
function formatBadges(badges) {
  return [
    ...badges,
    {
      alt: "\u{1F4AA} TypeScript: Strict",
      src: "https://img.shields.io/badge/%F0%9F%92%AA_typescript-strict-21bb42.svg"
    }
  ].sort(badgeSorter).map(formatBadge).join("\n");
}
function formatDescription(description) {
  if (!description.includes(". ")) {
    return description;
  }
  return "\n	" + description.replaceAll(". ", ".\n	") + "\n";
}
function removeEmojis(text) {
  return text.replaceAll(/\p{Emoji}/gu, "").trim();
}
export {
  blockREADME
};

==> create-typescript-app-2.22.1.tgz: package/lib/blocks/blockREADME.js <==
import { z } from "zod";
import { base } from "../base.js";
function printAttributes(attributes) {
  return Object.entries(attributes).map(([key, value]) => `${key}="${value}"`).sort().join(" ");
}
const zBadge = z.object({
  alt: z.string(),
  comments: z.object({
    after: z.string(),
    before: z.string()
  }).optional(),
  href: z.string().optional(),
  src: z.string()
});
const blockREADME = base.createBlock({
  about: {
    name: "README.md"
  },
  addons: {
    badges: z.array(zBadge).default([]),
    notices: z.array(z.string()).default([]),
    sections: z.array(z.string()).default([])
  },
  produce({ addons, options }) {
    const { badges, notices, sections } = addons;
    const explainer = options.explainer && `
${options.explainer.join("\n")}
`;
    const logo = options.logo && `
<img ${printAttributes({ align: "right", ...options.logo })}>
`;
    return {
      files: {
        "README.md": `<h1 align="center">${options.title}</h1>

<p align="center">${formatDescription(options.description)}</p>

<p align="center">
${formatBadges(badges)}
</p>
${[logo, explainer].filter(Boolean).join("")}
## Usage

${options.documentation.readme.usage}

## Development

See [\`.github/CONTRIBUTING.md\`](./.github/CONTRIBUTING.md), then [\`.github/DEVELOPMENT.md\`](./.github/DEVELOPMENT.md).
Thanks! ${options.emoji}
${[...sections, options.documentation.readme.additional].filter(Boolean).map((section) => `
${section}`).join("")}
${notices.length ? `
${notices.map((notice) => notice.trim()).join("\n\n")}` : ""}`
      }
    };
  }
});
function badgeSorter(a, b) {
  return removeEmojis(a.alt).localeCompare(removeEmojis(b.alt));
}
function formatBadge(badge) {
  const image = `<img alt="${badge.alt}" src="${badge.src}" />`;
  const tagged = badge.href ? `<a href="${badge.href}" target="_blank">${image}</a>` : image;
  const commented = badge.comments ? `${badge.comments.before}${tagged}${badge.comments.after}` : tagged;
  return `	${commented}`;
}
function formatBadges(badges) {
  return [
    ...badges,
    {
      alt: "\u{1F4AA} TypeScript: Strict",
      src: "https://img.shields.io/badge/%F0%9F%92%AA_typescript-strict-21bb42.svg"
    }
  ].sort(badgeSorter).map(formatBadge).join("\n");
}
function formatDescription(description) {
  if (!description.includes(". ")) {
    return description;
  }
  return "\n	" + description.replaceAll(". ", ".\n	") + "\n";
}
function removeEmojis(text) {
  return text.replaceAll(/\p{Emoji}/gu, "").trim();
}
export {
  blockREADME
};
